.. loam documentation master file, created by
   sphinx-quickstart on Sun Jan 28 13:32:29 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to loam's documentation!
================================

.. toctree::
   :maxdepth: 2
   :caption: Getting started

   sources/firststeps

.. toctree::
   :maxdepth: 2
   :caption: API Reference

   sources/api/base
   sources/api/cli
   sources/api/collections
   sources/api/parsers
   sources/api/tools
   sources/api/error

